@@ -1,3 +1,4 @@
+import re
 from typing import List, Tuple, Union
 from urllib.parse import parse_qsl, urlparse
 
@@ -9,7 +10,7 @@ from w3lib.url import url_query_cleaner
 __author__ = "Elton H.Y. Chou"
 
 __license__ = "MIT"
-__version__ = "0.0.4-beta"
+__version__ = "0.0.5"
 __maintainer__ = "Elton H.Y. Chou"
 __email__ = "plscd748@gmail.com"
 
@@ -110,7 +111,7 @@ def _super_cleaner(url: str, headers: dict = {}, cookies: dict = {}) -> str:
     page = _get_page(url, headers, cookies)
 
     if not page:
-        return _fbclid_cleaner(url)
+        return url
 
     canonical_url = _get_canonical_url(page)
     og_url = _get_og_url(page)
@@ -219,6 +220,12 @@ def _get_page(url: str, headers: dict = {}, cookies: dict = {}) -> BeautifulSoup
     -------
     BeautifulSoup
     """
+    session = requests.Session()
+    response = session.head(url)
+    content_type = response.headers["content-type"]
+    if not re.search("text/html", content_type):
+        return False
+
     response = requests.get(url, headers=headers, cookies=cookies)
 
     if response.status_code > 400:
